@@ -3,11 +3,9 @@ from pathlib import Path
 
 from nonebot import get_plugin_config
 
-
 # fmt:off
 class Config(BaseModel):
-    data_path: str = "data/course_schedule"
-    fort_path: str = Field(default_factory=lambda: str(
+    course_font_path: str = Field(default_factory=lambda: str(
         Path(__file__).parent / "resources" / "MapleMono-NF-CN-Medium.ttf"
     ))
 # fmt:on
